@@ -5,7 +5,7 @@ use warnings;
 
 use XSLoader;
 
-our $VERSION = '0.300002';
+our $VERSION = '0.400000';
 
 XSLoader::load( 'Devel::QuickCover', $VERSION );
 
@@ -39,10 +39,22 @@ sub import {
     }
 }
 
+sub set_output_directory {
+    my ($dir) = @_;
+    return unless $dir;
+
+    $CONFIG{output_directory} = $dir;
+}
+
+sub set_metadata {
+    my ($data) = @_;
+    return unless $data;
+
+    $CONFIG{metadata} = $data;
+}
+
 END {
-    if (!$CONFIG{'nodump'}) {
-        Devel::QuickCover::end();
-    }
+    Devel::QuickCover::end($CONFIG{'nodump'});
 }
 
 1;
@@ -59,7 +71,7 @@ Devel::QuickCover - Quick & dirty code coverage for Perl
 
 =head1 VERSION
 
-Version 0.300002
+Version 0.400000
 
 =head1 SYNOPSIS
 
@@ -96,6 +108,10 @@ in the coverage information.
 
 For now, we support calling C<start()> only once.
 
+When you call C<end()>, you can optionally pass a C<nodump>
+boolean argument, to indicate whether you wish to skip generating
+the cover files.
+
 =head1 AUTHORS
 
 =over 4
